@@ -16,9 +16,10 @@ var (
 // migrateCmd represents the migrate command
 var migrateCmd = &cobra.Command{
 	Use:   "migrate",
-	Short: "Migrate your configuration",
-	Long: `Migrate your configuration
-You can choose to print the output to stdout, or migrate your configuration in the format of your choice.
+	Short: "Migrate your config",
+	Long: `Migrate your config.
+
+You can choose to print the output to stdout, or migrate your config in the format of your choice.
 
 Example usage
 
@@ -32,8 +33,9 @@ Migrates the ~/myconfig.omp.json config file to toml and prints the result to st
 
 > oh-my-posh config migrate --config ~/myconfig.omp.json --format toml --write
 
-Migrates the  ~/myconfig.omp.json config file to toml and writes the result to your config file.
+Migrates the ~/myconfig.omp.json config file to toml and writes the result to your config file.
 A backup of the current config can be found at ~/myconfig.omp.json.bak.`,
+	Args: cobra.NoArgs,
 	Run: func(cmd *cobra.Command, args []string) {
 		env := &environment.ShellEnvironment{
 			Version: cliVersion,
@@ -42,7 +44,7 @@ A backup of the current config can be found at ~/myconfig.omp.json.bak.`,
 				Migrate: true,
 			},
 		}
-		env.Init(false)
+		env.Init()
 		defer env.Close()
 		cfg := engine.LoadConfig(env)
 		if write {
@@ -55,7 +57,7 @@ A backup of the current config can be found at ~/myconfig.omp.json.bak.`,
 }
 
 func init() { //nolint:gochecknoinits
-	migrateCmd.Flags().BoolVarP(&write, "write", "w", false, "write the migrated configuration back to the config file")
-	migrateCmd.Flags().StringVarP(&format, "format", "f", "json", "the configuration format to migrate to")
+	migrateCmd.Flags().BoolVarP(&write, "write", "w", false, "write the migrated config back to the config file")
+	migrateCmd.Flags().StringVarP(&format, "format", "f", "json", "the config format to migrate to")
 	configCmd.AddCommand(migrateCmd)
 }
