@@ -1,28 +1,24 @@
 package environment
 
-import "sync"
-
 type concurrentMap struct {
 	values map[string]interface{}
-	lock   sync.RWMutex
 }
 
 func newConcurrentMap() *concurrentMap {
 	return &concurrentMap{
 		values: make(map[string]interface{}),
-		lock:   sync.RWMutex{},
 	}
 }
 
 func (c *concurrentMap) set(key string, value interface{}) {
-	c.lock.Lock()
-	defer c.lock.Unlock()
+	lock.Lock()
+	defer lock.Unlock()
 	c.values[key] = value
 }
 
 func (c *concurrentMap) get(key string) (interface{}, bool) {
-	c.lock.RLock()
-	defer c.lock.RUnlock()
+	lock.RLock()
+	defer lock.RUnlock()
 	if val, ok := c.values[key]; ok {
 		return val, true
 	}
@@ -30,8 +26,8 @@ func (c *concurrentMap) get(key string) (interface{}, bool) {
 }
 
 func (c *concurrentMap) remove(key string) {
-	c.lock.RLock()
-	defer c.lock.RUnlock()
+	lock.RLock()
+	defer lock.RUnlock()
 	delete(c.values, key)
 }
 
